@@ -6,10 +6,7 @@
     :license: GNU GPLv2
     :author: Frost Ming<mianghong@gmail.com>
 """
-try:
-    from shutil import get_terminal_size
-except ImportError:
-    from backports.shutil_get_terminal_size import get_terminal_size
+from shutil import get_terminal_size
 
 SIZE = tuple(get_terminal_size((80, 24)))
 CHARS = "ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789|!?.+-_=@#$%&()/:;,' \""
